<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              wizplugins.com
 * @since             1.0.0
 * @package           Forfwc
 *
 * @wordpress-plugin
 * Plugin Name:       Focus On Reviews for WooCommerce
 * Plugin URI:        https://wizplugins.com/plugin-product/focus-on-reviews-for-woocommerce/
 * Description:       Show reviews first for an added boost in sales. When enabled and a review is present, the review tab will open on page load, using the power of reviews to help you sell more
 * Version:           1.0.0
 * Author:            Wiz Plugins
 * Author URI:        wizplugins.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       forfwc
 * Domain Path:       /languages
 */
if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( function_exists( 'forfwc_fs' ) ) {
    forfwc_fs()->set_basename( false, __FILE__ );
} else {
    if ( !function_exists( 'forfwc_fs' ) ) {
        // If this file is called directly, abort.
        
        if ( !function_exists( 'forfwc_fs' ) ) {
            // Create a helper function for easy SDK access.
            function forfwc_fs()
            {
                global  $forfwc_fs ;
                
                if ( !isset( $forfwc_fs ) ) {
                    // Include Freemius SDK.
                    require_once dirname( __FILE__ ) . '/freemius/start.php';
                    $forfwc_fs = fs_dynamic_init( array(
                        'id'             => '3893',
                        'slug'           => 'focus-on-reviews-for-woocommerce',
                        'type'           => 'plugin',
                        'public_key'     => 'pk_1f05660aba8415e48ac31ed028ce0',
                        'is_premium'     => false,
                        'premium_suffix' => 'Pro',
                        'has_addons'     => false,
                        'has_paid_plans' => true,
                        'menu'           => array(
                        'support' => false,
                    ),
                        'is_live'        => true,
                    ) );
                }
                
                return $forfwc_fs;
            }
            
            // Init Freemius.
            forfwc_fs();
            // Signal that SDK was initiated.
            do_action( 'forfwc_fs_loaded' );
        }
    
    }
    if ( !defined( 'WPINC' ) ) {
        die;
    }
    /**
     * Currently plugin version.
     * Start at version 1.0.0 and use SemVer - https://semver.org
     * Rename this for your plugin and update it as you release new versions.
     */
    define( 'FORFWC_VERSION', '1.0.0' );
    /**
     * The code that runs during plugin activation.
     * This action is documented in includes/class-forfwc-activator.php
     */
    function activate_forfwc()
    {
        require_once plugin_dir_path( __FILE__ ) . 'includes/class-forfwc-activator.php';
        Forfwc_Activator::activate();
        do_action( 'forfwc_default_options' );
    }
    
    /**
     * The code that runs during plugin deactivation.
     * This action is documented in includes/class-forfwc-deactivator.php
     */
    function deactivate_forfwc()
    {
        require_once plugin_dir_path( __FILE__ ) . 'includes/class-forfwc-deactivator.php';
        Forfwc_Deactivator::deactivate();
    }
    
    register_activation_hook( __FILE__, 'activate_forfwc' );
    register_deactivation_hook( __FILE__, 'deactivate_forfwc' );
    // Set default values here
    function forfwc_default_values()
    {
        // Form settings
        update_option( 'forfwc_settings_checkbox0', 'no' );
        update_option( 'forfwc_settings_text10', 'li#tab-title-description' );
        update_option( 'forfwc_settings_text20', 'div#tab-description' );
    }
    
    add_action( 'forfwc_default_options', 'forfwc_default_values' );
    /**
     * The core plugin class that is used to define internationalization,
     * admin-specific hooks, and public-facing site hooks.
     */
    require plugin_dir_path( __FILE__ ) . 'includes/class-forfwc.php';
    /**
     * Begins execution of the plugin.
     *
     * Since everything within the plugin is registered via hooks,
     * then kicking off the plugin from this point in the file does
     * not affect the page life cycle.
     *
     * @since    1.0.0
     */
    function run_forfwc()
    {
        $plugin = new Forfwc();
        $plugin->run();
    }
    
    run_forfwc();
    /*
     * Add settings link to plugin list page
     * 
     */
    add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'forfwc_pro_add_plugin_page_settings_link' );
    function forfwc_pro_add_plugin_page_settings_link( $links )
    {
        $links[] = '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=products&section=open_reviews_first' ) . '">' . __( 'Settings' ) . '</a>';
        return $links;
    }
    
    // Not like register_uninstall_hook(), you do NOT have to use a static function.
    
    if ( !function_exists( 'forfwc_fs_uninstall_cleanup' ) ) {
        /**
         * Plugin uninstall cleanup.
         *
         * @since 1.0.0
         */
        function forfwc_fs_uninstall_cleanup()
        {
            // Delete all the plugin options
            delete_option( 'forfwc_settings' );
        }
        
        forfwc_fs()->add_action( 'after_uninstall', 'forfwc_fs_uninstall_cleanup' );
    }

}
